Module clock
pas_
external
0.14.1
Module clock
Module Items
Modules
Traits
Type Aliases
In crate pas_
external
pas_external
Module
clock
Modules

jiff
Jiff is a datetime library for Rust that encourages you to jump into the pit of success. The focus of this library is providing high level datetime primitives that are difficult to misuse and have reasonable performance.
native
Traits

Clock
Wall-clock readouts. Single port for “what time is it?” across all surfaces.
Timer
Async scheduling primitive. Single port for “wait N ms” / “yield event-loop tick”.
Type Aliases

ArcClock
Convenience aliases for the common injection shape.
ArcTimer